import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

enum AnimationType {
  //Clasificamos de manera personalizada, para utilizarlo despues
  normal,
  fadeIn
}

class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions(
      {@required this.context,
      @required this.child,
      this.animation = AnimationType.normal,
      this.duration = const Duration(
          milliseconds:
              300), //Si no mencionamos quees una constante no nos votara error,  sera constante siempre y cuando no enviemos dicho campo
      this.replacement = false}) {
    // Duration duration
    // }):this.duration = duration ?? Duration(milliseconds: 300){

    switch (this.animation) {
      case AnimationType.normal:
        this._normalTransition();
        break;
      case AnimationType.fadeIn:
        this._fadeInTransition();
        break;
    }
  }

  void _pushPage(Route route) => Navigator.push(context, route);
  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

  void _normalTransition() {
    final route = MaterialPageRoute(
        builder: (_) =>
            this.child); //Widget de ruta simple, indicando el el page widget

    (this.replacement)
        ? this._pushReplacementPage(route)
        : this._pushPage(route);
  }

  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (BuildContext context, _, __) => this
            .child, //Toma el child de aqui //Widget de ruta compuesta, aparte de indicar el page widget incluye las transicion que queremos añadir
        transitionDuration: this.duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
              child: child,
              opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                  CurvedAnimation(curve: Curves.easeInOut, parent: animation)));
        });

    // Navigator.push(context, route);
    (this.replacement) ? _pushPage(route) : _pushReplacementPage(route);
  }
}
